---
project: {{NAME}}
summary: {{SUMMARY}}
project_url: {{WEBSITE}}
author: {{AUTHORS}}
email: {{EMAIL}}
src_dir: ./src
output_dir: ./docs/ford
project_github: {{REPOSITORY}}
display: public
         private
proc_internals: true
coloured_edges: true
graph_maxdepth: 6
---

{{SUMMARY}}
